@@ -22,6 +22,7 @@ pgpy = lazy_import.lazy_module("pgpy")
 
 
 AES = lazy_import.lazy_module("Crypto.Cipher.AES")
+Salsa20 = lazy_import.lazy_module("Crypto.Cipher.Salsa20")
 ARC4 = lazy_import.lazy_module("Crypto.Cipher.ARC4")
 DES = lazy_import.lazy_module("Crypto.Cipher.DES")
 ChaCha20 = lazy_import.lazy_module("Crypto.Cipher.ChaCha20")
@@ -705,6 +706,58 @@ class EncryptionEncoding(ChepyCore):
             self.state = cipher.decrypt(self._convert_to_bytes())
             return self
 
+    @ChepyDecorators.call_stack
+    def salsa20_encrypt(
+        self,
+        key: str,
+        nonce: str = "0000000000000000",
+        key_format: str = "hex",
+        nonce_format: str = "hex",
+    ) -> EncryptionEncodingT:
+        """Encrypt raw state with Salsa 20 rounds
+
+        Args:
+            key (str): Required. The secret key
+            nonce (str, optional): Nonce. Defaults to '0000000000000000'.
+            key_format (str, optional): Format of key. Defaults to 'hex'.
+            nonce_format (str, optional): Format of nonce. Defaults to 'hex'.
+
+        Returns:
+            Chepy: The Chepy object.
+        """
+
+        key, nonce = self._convert_key(key, nonce, key_format, nonce_format)
+
+        cipher = Salsa20.new(key=key, nonce=nonce)
+        self.state = cipher.encrypt(self._convert_to_bytes())
+        return self
+
+    @ChepyDecorators.call_stack
+    def salsa20_decrypt(
+        self,
+        key: str,
+        nonce: str = "0000000000000000",
+        key_format: str = "hex",
+        nonce_format: str = "hex",
+    ) -> EncryptionEncodingT:
+        """Decrypt raw state encrypted with ChaCha 20 rounds.
+
+        Args:
+            key (str): Required. The secret key
+            nonce (str, optional): nonce for certain modes only. Defaults to '0000000000000000'.
+            key_format (str, optional): Format of key. Defaults to 'hex'.
+            nonce_format (str, optional): Format of nonce. Defaults to 'hex'.
+
+        Returns:
+            Chepy: The Chepy object.
+        """
+
+        key, nonce = self._convert_key(key, nonce, key_format, nonce_format)
+
+        cipher = Salsa20.new(key=key, nonce=nonce)
+        self.state = cipher.decrypt(self._convert_to_bytes())
+        return self
+
     @ChepyDecorators.call_stack
     def chacha_encrypt(
         self,
@@ -2064,3 +2117,109 @@ class EncryptionEncoding(ChepyCore):
 
         self.state = bytes(decoded_bytes)
         return self
+
+    @ChepyDecorators.call_stack
+    def sms_encode_multitap(self):
+        """
+        Encode text to multi-tap SMS format.
+        Example: 'sun' -> '7778866'
+        Preserves special characters that aren't on phone keys.
+
+        Returns:
+            Chepy: The Chepy object.
+        """
+        KEY_MAP = {
+            "2": "ABC",
+            "3": "DEF",
+            "4": "GHI",
+            "5": "JKL",
+            "6": "MNO",
+            "7": "PQRS",
+            "8": "TUV",
+            "9": "WXYZ",
+            "0": " ",
+        }
+        REVERSE_MAP = {}
+
+        for key, letters in KEY_MAP.items():
+            for i, letter in enumerate(letters):
+                REVERSE_MAP[letter] = key * (i + 1)
+
+        result = []
+
+        for char in self._convert_to_str():
+            upper_char = char.upper()
+
+            # Check if character can be encoded
+            if upper_char in REVERSE_MAP:
+                result.append(REVERSE_MAP[upper_char])
+            else:
+                # Preserve special characters as-is
+                result.append(char)
+
+        self.state = "".join(result)
+        return self
+
+    @ChepyDecorators.call_stack
+    def sms_decode_multitap(self):
+        """
+        Decode multi-tap SMS format to text.
+        Example: '7778866' -> 'SUN'
+        Preserves special characters that aren't numeric keypresses.
+
+        Returns:
+            Chepy: The Chepy object.
+        """
+        KEY_MAP = {
+            "2": "ABC",
+            "3": "DEF",
+            "4": "GHI",
+            "5": "JKL",
+            "6": "MNO",
+            "7": "PQRS",
+            "8": "TUV",
+            "9": "WXYZ",
+            "0": " ",
+        }
+
+        result = []
+        i = 0
+
+        encoded = self._convert_to_str()
+
+        while i < len(encoded):
+            current_char = encoded[i]
+
+            # If it's not a digit, preserve it as-is
+            if not current_char.isdigit():
+                result.append(current_char)
+                i += 1
+                continue
+
+            # If it's not a valid key, preserve it
+            if current_char not in KEY_MAP:  # pragma: no cover
+                result.append(current_char)
+                i += 1
+                continue
+
+            letters = KEY_MAP[current_char]
+            letters_count = len(letters)
+
+            # Count consecutive same digits
+            count = 0
+            while i < len(encoded) and encoded[i] == current_char:
+                count += 1
+                i += 1
+
+            # Decode groups of presses, handling wrapping
+            while count > 0:
+                presses_for_this_letter = count % letters_count
+                if presses_for_this_letter == 0:
+                    presses_for_this_letter = letters_count
+
+                letter_index = presses_for_this_letter - 1
+                result.append(letters[letter_index])
+                count -= presses_for_this_letter
+
+        self.state = "".join(result)
+        return self
